ReceiverMac

Struct ReceiverMac 

pub struct ReceiverMac {
    pub key_id: u32,
    pub mac: [u8; 16],
}
Receiver-Specific-MAC (Spec 7.3.6.3 ReceiverSpecificMAC).

Wenn ein Sender ein Ciphertext an N Receiver mit gleicher Suite aber unterschiedlichen Keys schickt, wird pro Receiver ein 16-byte Truncated-HMAC berechnet. Die Wire-Repraesentation ist eine Sequenz von (key_id, mac)-Paaren im SEC_POSTFIX.

key_id ist die Spec-konforme 4-Byte-ID (typisch low-32-bits des Sender-seitigen CryptoHandle fuer diesen Receiver), anhand derer der Empfaenger seinen spezifischen MAC-Eintrag findet.

Fields

key_id: u32

4-byte CryptoTransformKeyId aus 7.3.6.3.

mac: [u8; 16]

16-byte Truncated-HMAC-SHA256 ueber den Ciphertext.

Implementations

Source

impl ReceiverMac

pub const WIRE_SIZE: usize

Wire-Size eines einzelnen ReceiverMac-Eintrags (Spec 7.3.6.3).